@@ -3,10 +3,10 @@ import os
 import sys
 from pathlib import Path
 
-from CSharpCCF.lexer import TokenType
-from CSharpCCF.static_analyzer import StaticAnalyzer, File
+from .lexer import TokenType
+from .static_analyzer import StaticAnalyzer, File
 
-__version__ = "0.1.6"
+__version__ = "0.1.8"
 
 
 def get_files(path):
